==> PyFetchDB-2.1.6.tar.gz: PyFetchDB-2.1.6/setup.py <==
from distutils.core import setup
setup(
  name = 'PyFetchDB',         # How you named your package folder (MyLib)
  packages = ['PyFetchDB'],   # Chose the same as "name"
  version = '2.1.6',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Small, easy to use, python database.',   # Give a short description about your library
  author = 'Mathieu Courcier-Flores',                   # Type in your name
  author_email = 'Mathieucourcierflores@gmail.com',      # Type in your E-Mail
  url = 'https://pyfetch.netlify.app/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Werner-Zeigler/PyFetchDB/archive/refs/tags/v2.1.6.tar.gz',    # I explain this later on
  keywords = ['Python', 'Easy', 'Database'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which python versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> PyFetchDB-2.2.tar.gz: PyFetchDB-2.2/setup.py <==
from distutils.core import setup
setup(
  name = 'PyFetchDB',         # How you named your package folder (MyLib)
  packages = ['PyFetchDB'],   # Chose the same as "name"
  version = '2.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Small, easy to use, python database.',   # Give a short description about your library
  author = 'Mathieu Courcier-Flores',                   # Type in your name
  author_email = 'Mathieucourcierflores@gmail.com',      # Type in your E-Mail
  url = 'https://pyfetch.netlify.app/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Werner-Zeigler/PyFetchDB/archive/refs/tags/v2.2.tar.gz',    # I explain this later on
  keywords = ['Python', 'Easy', 'Database'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which python versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
